
CREATE TABLE publishers
(
	pub_id char(4) PRIMARY KEY NOT NULL,
	pub_name varchar(40) NULL,
	city varchar(20) NULL,
	state char(2) NULL,
	country varchar(30) NULL DEFAULT ('USA')
);
	
	
CREATE TABLE stores
(
	stor_id char(4) PRIMARY KEY NOT NULL,
	stor_name varchar(40) NULL,
	stor_address varchar(40) NULL,
	city varchar(20) NULL,
	state char(2) NULL,
	zip char(5) NULL
);

CREATE TABLE jobs
(
	job_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	job_desc varchar(50) NOT NULL DEFAULT ('New Position - title not formalized yet'),
	min_lvl tinyint NOT NULL,
	max_lvl tinyint NOT NULL
);

CREATE TABLE pub_info(
	pub_id char(4) NOT NULL,
	logo image NULL,
	pr_info text NULL,
	constraint fk_pub_infopublishers foreign key (pub_id) references publishers (pub_id)
);

CREATE TABLE discounts(
	discounttype varchar(40) NOT NULL,
	stor_id char(4) NULL,
	lowqty smallint NULL,
	highqty smallint NULL,
	discount decimal(4, 2) NOT NULL,
	constraint fk_discountsstores foreign key(stor_id) references stores (stor_id)
); 


CREATE TABLE titleauthor(
	au_id INTEGER NOT NULL,
	title_id INTEGER NOT NULL,
	au_ord INTEGER NULL,
	royaltyper INTEGER NULL,
	constraint fk_titleauthorauthors foreign key(au_id) references authors (au_id),
	constraint fk_titleauthortitles foreign key(title_id) references titles (title_id)
);


CREATE TABLE authors(
	au_id TEXT PRIMARY KEY NOT NULL,
	au_lname varchar(40) NOT NULL,
	au_fname varchar(20) NOT NULL,
	phone char(12) NOT NULL DEFAULT ('UNKNOWN'),
	address varchar(40) NULL,
	city varchar(20) NULL,
	state char(2) NULL,
	zip char(5) NULL,
	contract bit NOT NULL
);

CREATE TABLE titles(
	title_id TEXT PRIMARY KEY NOT NULL,
	title varchar(80) NOT NULL,
	type char(12) NOT NULL DEFAULT ('UNDECIDED'),
	pub_id char(4) NULL,
	price money NULL,
	advance money NULL,
	royalty int NULL,
	ytd_sales int NULL,
	notes varchar(200) NULL,
	pubdate datetime NOT NULL DEFAULT (getdate()),
	constraint fk_titlepublishers foreign key (pub_id) references publishers (pub_id)
 );
 
CREATE TABLE roysched(
	title_id INTEGER NOT NULL,
	lorange int NULL,
	hirange int NULL,
	royalty int NULL,
	constraint fk_royschedtitles foreign key(title_id) references titles (title_id)
);

CREATE TABLE sales(
	stor_id char(4) NOT NULL,
	ord_num varchar(20) NOT NULL,
	ord_date datetime NOT NULL,
	qty smallint NOT NULL,
	payterms varchar(12) NOT NULL,
	title_id tid NOT NULL,
	constraint fk_salesstores foreign key(stor_id) references stores (stor_id),
	constraint fk_salestitles  foreign key(title_id) references titles (title_id)
);


CREATE TABLE employee(
	emp_id TEXT PRIMARY KEY NOT NULL,
	fname varchar(20) NOT NULL,
	minit char(1) NULL,
	lname varchar(30) NOT NULL,
	job_id smallint NOT NULL DEFAULT ((1)),
	job_lvl tinyint NULL DEFAULT ((10)),
	pub_id char(4) NOT NULL DEFAULT ('9952'),
	hire_date datetime NOT NULL DEFAULT (getdate()),
	constraint fk_employeejobs foreign key(job_id) references jobs (job_id),
	constraint fk_employeepublishers  foreign key(pub_id) references publishers (pub_id)
);



CREATE VIEW titleview
AS
select title, au_ord, au_lname, price, ytd_sales, pub_id
from authors, titles, titleauthor
where authors.au_id = titleauthor.au_id
   AND titles.title_id = titleauthor.title_id;
   
